------------------------------------------------------------------------
-- Licensed Materials - Property of IBM
--
-- Copyright IBM Corporation 2016, 2017. All Rights Reserved.
--
-- US Government Users Restricted Rights- Use, duplication or disclosure
-- restricted by GSA ADP Schedule Contract with IBM Corp. 
------------------------------------------------------------------------
-- Script Name:       custom_queries.sql
-- FTM IP: Define custom queries for the OAC
------------------------------------------------------------------------

CREATE VARIABLE FTM.QRY_VALUE CLOB(1048576);
SET FTM.QRY_VALUE = '<customQuery 
  menu="Statistical Data" 
  title="Incoming Transaction Latency" 
  resource="txn_payment" 
  permission="view" 
  qry="SELECT INTEGER(TIMESTAMPDIFF(1, CHAR(RESPONSE.STATUS_DATE - TIMESTAMP_FORMAT(TXN.TXN_DATA1, ''YYYY-MM-DD-HH24:MI:SS.FF'')))/1000) AS LATENCY_MILLIS,
  REQUEST.CID AS MSG_ID, REQUEST.CREATED AS MSG_CREATED, REQUEST.ID AS ID
  FROM $DBSchema.OBJ_BASE AS REQUEST 
		JOIN $DBSchema.TRANSACTION_BASE AS TXN ON REQUEST.ID = TXN.TRANSMISSION_ID 
		JOIN $DBSchema.OBJ_OBJ_REL AS REL ON REQUEST.ID = REL.OBJ1_ID 
		JOIN $DBSchema.OBJ_BASE AS RESPONSE ON REL.OBJ2_ID = RESPONSE.ID 
  WHERE TXN.TXN_DATA1 IS NOT NULL
    AND REQUEST.SUBTYPE = ''IP_FROM_CSM_INSTR_PT'' AND REQUEST.STATUS = ''S_InPTComplete''
    AND RESPONSE.SUBTYPE = ''IP_TO_CSM_PSTAT_PT'' AND RESPONSE.STATUS = ''S_OutPTSent''
	/*[*/ AND REQUEST.CID LIKE ?/*]*/ 
	/*[*/ AND REQUEST.CREATED > $DBSchema.FTM_TIMESTAMP() - ? MINUTES/*]*/  " >
  <param input="text"   
    type="string" 
    label="MSG_ID" 
    size="" 
     />   
  <param input="text"   
    type="integer" 
    label="created within the last xx minutes" 
    maxlength="10" />   
  <link 
    to="obj_details.jsp"  
    task="viewDetails"
    source="%%[source]%%">
    <param label="id" value="%%ID%%" /> 	   
  </link>  
</customQuery>';

MERGE INTO UI_USR_PREFS AS U
	USING (VALUES('SCRIPT:custom_queries.sql', 'REPORT', 'Incoming Transaction Latency')) AS T(A,B,C)
	ON (U.USER_NAME = T.A AND U.TYPE = T.B AND U.LABEL = T.C)
	WHEN MATCHED 
		THEN UPDATE SET VALUE = FTM.QRY_VALUE
	WHEN NOT MATCHED
		THEN INSERT VALUES(T.A, T.B, T.C, FTM.QRY_VALUE);

SET FTM.QRY_VALUE = '<customQuery 
  menu="Statistical Data" 
  title="Outgoing Transaction Latency" 
  resource="txn_payment" 
  permission="view" 
  qry="SELECT INTEGER(TIMESTAMPDIFF(1, CHAR(PT2.STATUS_DATE - TIMESTAMP_FORMAT(TX1.TXN_DATA1, ''YYYY-MM-DD-HH24:MI:SS.FF'')))/1000) AS LATENCY_IN_MILLIS,
  INTEGER(TIMESTAMPDIFF(1, CHAR(PT4.STATUS_DATE - TIMESTAMP_FORMAT(TX3.TXN_DATA1, ''YYYY-MM-DD-HH24:MI:SS.FF'')))/1000) AS LATENCY_OUT_MILLIS,
  PT1.CID AS MSG_ID, PT1.CREATED AS MSG_CREATED, PT1.ID AS ID
  FROM $DBSchema.OBJ_BASE AS PT1 
		JOIN $DBSchema.TRANSACTION_BASE AS TX1 ON PT1.ID = TX1.TRANSMISSION_ID 
		JOIN $DBSchema.OBJ_OBJ_REL AS REL1 ON PT1.ID = REL1.OBJ1_ID 
		JOIN $DBSchema.OBJ_BASE AS PT2 ON REL1.OBJ2_ID = PT2.ID 
		JOIN $DBSchema.OBJ_OBJ_REL AS REL2 ON PT2.ID = REL2.OBJ2_ID 
		JOIN $DBSchema.OBJ_BASE AS PT3 ON REL2.OBJ1_ID = PT3.ID 
		JOIN $DBSchema.OBJ_OBJ_REL AS REL3 ON PT1.ID = REL3.OBJ1_ID 
		JOIN $DBSchema.OBJ_BASE AS PT4 ON REL3.OBJ2_ID = PT4.ID 
		JOIN $DBSchema.TRANSACTION_BASE AS TX3 ON PT3.ID = TX3.TRANSMISSION_ID 
  WHERE TX1.TXN_DATA1 IS NOT NULL AND TX1.TXN_DATA1 IS NOT NULL
	AND PT1.SUBTYPE = ''IP_FROM_DBTR_INSTR_PT'' AND PT1.STATUS = ''S_InPTComplete''
	AND PT2.SUBTYPE = ''IP_TO_CSM_INSTR_PT'' AND PT2.STATUS = ''S_OutPTSent''
	AND PT3.SUBTYPE = ''IP_FROM_CSM_PSTAT_PT'' AND PT3.STATUS = ''S_InPTComplete''
	AND PT4.SUBTYPE = ''IP_TO_DBTR_PSTAT_PT'' AND PT4.STATUS = ''S_OutPTSent'' 
	/*[*/ AND PT1.CID LIKE ?/*]*/ 
	/*[*/ AND PT1.CREATED > $DBSchema.FTM_TIMESTAMP() - ? MINUTES/*]*/  " >
  <param input="text"   
    type="string" 
    label="MSG_ID" 
    size="" 
     />   
  <param input="text"   
    type="integer" 
    label="created within the last xx minutes" 
    maxlength="10" />   
  <link 
    to="obj_details.jsp"  
    task="viewDetails"
    source="%%[source]%%">
    <param label="id" value="%%ID%%" /> 	   
  </link>  
</customQuery>';

MERGE INTO UI_USR_PREFS AS U
	USING (VALUES('SCRIPT:custom_queries.sql', 'REPORT', 'Outgoing Transaction Latency')) AS T(A,B,C)
	ON (U.USER_NAME = T.A AND U.TYPE = T.B AND U.LABEL = T.C)
	WHEN MATCHED 
		THEN UPDATE SET VALUE = FTM.QRY_VALUE
	WHEN NOT MATCHED
		THEN INSERT VALUES(T.A, T.B, T.C, FTM.QRY_VALUE);

DROP VARIABLE FTM.QRY_VALUE;
COMMIT;
